class InterpreterData with _InterpreterKeys, _InterpreterPatterns {}

mixin _InterpreterKeys {
  final String orderKey = 'orderKey';
  final String deliveryKey = 'deliveryKey';
  final String stockTransferKey = 'stockTransferKey';
  final String itemKey = 'itemKey';

  // QR-Code / 2D-Code:
  // \~PLANDW00~\\~SLOC366I~\\~TMAT1420796~\
  // \~PLANDW00~\\~SLOC366I~\\~TMAT14207969~\
  // \~PLANDW00~\\~SLOC101I~\\~EQUI395770~\\~TMAT5092201~\
  final String plantKey = 'PLAN';
  final String storageLocationKey = 'SLOC';
  final String equipmentNumberKey = 'EQUI';
  final String technicalMaterialKey = 'TMAT';
}

mixin _InterpreterPatterns {
  /// To check if there is a FNC1 prefix
  final String unknownFNC1PrefixPattern = r'^\D+';

  final String digitsOnlyPattern = r'^\d*$';

  /// Order number pattern:
  /// - is Integer
  /// - starts with 49 or 10
  /// - has length of 10
  final String orderNumberPattern = r'(?:10|49)\d{8}';

  /// Delivery Number pattern:
  /// - is Integer
  /// - starts with 32
  /// - has length of 10
  final String deliveryNumberPattern = r'32\d{8}';

  /// Stock transfer pattern:
  /// - is Integer
  /// - starts with 319
  /// - has length of 10
  final String stockTransferPattern = r'319\d{7}';

  /// Order Item Number pattern:
  /// - is Integer
  /// - Number is smaller than 1000
  /// - Number is fully dividable by 10 (if input is not manual)
  /// - String has length of 5 or 6
  final String orderItemPattern = r'0{2,3}\d{2}0';

  /// Pipe separator pattern
  final String pipePattern = r'\|';
}
